use std::sync::{Arc, Mutex};

use crate::{MlsClient, screens::Screens};

/// Context which is valid only when logged in.
#[derive(Clone)]
pub struct MlsContext {
    /// Client for mls operations.
    /// It has ciphers, crypto provider, etc.
    /// It is used to create groups, send messages, etc.
    pub mls_client: MlsClient,
    /// ID of the user from the server.
    pub user_id: String,
    /// Current group which user is in.
    pub current_group: Option<String>,
}

pub struct ClientCTX {
    pub email: String,
    pub password: String,
    pub machine_id: String,
    pub current_screen: Screens,
    pub sqlite_connection: Arc<Mutex<rusqlite::Connection>>,
    pub mls_context: Option<MlsContext>,
}

impl ClientCTX {
    pub fn new(sqlite_connection: Arc<Mutex<rusqlite::Connection>>) -> Self {
        Self {
            email: String::new(),
            password: String::new(),
            machine_id: String::new(),
            current_screen: Screens::Login,
            sqlite_connection,
            mls_context: None,
        }
    }
}
