use std::sync::{Arc, Mutex};

use rusqlite::{Connection, OptionalExtension};

#[derive(Debug, Clone)]
pub struct GroupNamesStorage {
    pub connection: Arc<Mutex<Connection>>,
}

impl GroupNamesStorage {
    pub fn new(connection: Arc<Mutex<Connection>>) -> Self {
        Self { connection }
    }

    pub fn set_name(&self, chat_id: &str, name: &str) -> anyhow::Result<()> {
        let conn = self
            .connection
            .lock()
            .expect("Connection mutext is poisoned. It's a critical error. Exiting.");
        conn.execute(
            "INSERT INTO mls_cli_group_names(
                id, 
                name 
            ) VALUES (
                :id, 
                :name
            ) ON CONFLICT(id) DO UPDATE SET name=excluded.name",
            rusqlite::named_params![
                ":id": chat_id,
                ":name": name
            ],
        )?;
        Ok(())
    }

    pub fn get_name(&self, group_id: &str) -> anyhow::Result<Option<String>> {
        let conn = self
            .connection
            .lock()
            .expect("Connection mutext is poisoned. It's a critical error. Exiting.");
        conn.query_row(
            "SELECT name
            FROM mls_cli_group_names 
            WHERE id = :id",
            rusqlite::named_params![
                ":id": group_id,
            ],
            |row| row.get(0),
        )
        .optional()
        .map_err(anyhow::Error::from)
    }

    pub fn get_id(&self, name: &str) -> anyhow::Result<Option<String>> {
        let conn = self
            .connection
            .lock()
            .expect("Connection mutext is poisoned. It's a critical error. Exiting.");
        conn.query_row(
            "SELECT 
                id
            FROM mls_cli_group_names 
            WHERE name = :name",
            rusqlite::named_params![
                ":name": name,
            ],
            |row| row.get(0),
        )
        .optional()
        .map_err(anyhow::Error::from)
    }
}
