use std::sync::LazyLock;

use rusqlite_migration::{M, Migrations};

pub static MIGRATIONS: LazyLock<Migrations> = LazyLock::new(|| {
    Migrations::new(vec![
        // Initial migration
        M::up(
            r#"
            CREATE TABLE mls_group (
                group_id BLOB PRIMARY KEY,
                snapshot BLOB NOT NULL
            ) WITHOUT ROWID;

            CREATE TABLE epoch (
                group_id BLOB,
                epoch_id INTEGER,
                epoch_data BLOB NOT NULL,
                FOREIGN KEY (group_id) REFERENCES mls_group (group_id) ON DELETE CASCADE
                PRIMARY KEY (group_id, epoch_id)
            ) WITHOUT ROWID;

            CREATE TABLE key_package (
                id BLOB PRIMARY KEY,
                expiration INTEGER,
                data BLOB NOT NULL
            ) WITHOUT ROWID;
            CREATE INDEX key_package_exp ON key_package (expiration);

            CREATE TABLE psk (
                psk_id BLOB PRIMARY KEY,
                data BLOB NOT NULL
            ) WITHOUT ROWID;

            CREATE TABLE IF NOT EXISTS mls_cli_messages (
                id INTEGER PRIMARY KEY AUTOINCREMENT,
                group_id BLOB NOT NULL,
                sender_id INT NOT NULL,
                data BLOB NOT NULL,
                epoch_id UNSIGNED BIG INT NOT NULL,
                created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
                FOREIGN KEY (group_id) REFERENCES mls_group (group_id) ON DELETE CASCADE
            );
            CREATE INDEX IF NOT EXISTS idx_message_group_id ON mls_cli_messages(group_id);

            CREATE TABLE IF NOT EXISTS mls_cli_userdata (
                user_id TEXT PRIMARY KEY,
                secret_key BLOB NOT NULL,
                public_key BLOB NOT NULL
            ) WITHOUT ROWID;

            CREATE TABLE IF NOT EXISTS mls_cli_group_names (
                id TEXT NOT NULL PRIMARY KEY,
                name TEXT NOT NULL
            ) WITHOUT ROWID;

            "#,
        )
        .down(
            r#"
            DROP TABLE mls_cli_messages;
            DROP TABLE mls_cli_userdata;
            DROP TABLE mls_group;
            DROP TABLE epoch;
            DROP TABLE key_package;
            DROP TABLE psk;
            DROP TABLE mls_cli_group_names;
            "#,
        ),
    ])
});

#[cfg(test)]
mod tests {
    use super::*;

    // Validating that migrations are correctly defined. It is enough to test in the sync context,
    // because under the hood, tokio_rusqlite executes the migrations in a sync context anyway.
    #[test]
    fn migrations_test() {
        assert!(MIGRATIONS.validate().is_ok());
    }
}
