use egui::Color32;

use crate::{Screens, ctx::ClientCTX};

#[derive(Default)]
pub struct LoginScreen {
    email: String,
    password: String,
    highlight_password: bool,
    highlight_email: bool,
}

impl LoginScreen {
    pub fn update(&mut self, ctx: &mut ClientCTX, ui: &mut egui::Ui) {
        ui.vertical_centered(|ui| {
            let mut email_field = egui::TextEdit::singleline(&mut self.email).hint_text("Email");
            let mut password_field = egui::TextEdit::singleline(&mut self.password)
                .password(true)
                .hint_text("Password");
            if self.highlight_email {
                email_field = email_field.background_color(Color32::RED);
            }
            if self.highlight_password {
                password_field = password_field.background_color(Color32::RED);
            }
            ui.add(email_field);
            ui.add(password_field);
            if ui.button("Login").clicked() || ui.input(|inp| inp.key_pressed(egui::Key::Enter)) {
                self.highlight_email = self.email.is_empty();
                self.highlight_password = self.password.is_empty();
                if self.highlight_password || self.highlight_email {
                    return;
                }
                ctx.password = self.password.clone();
                ctx.email = self.email.clone();
                self.password.clear();
                ctx.current_screen = Screens::Chats;
            }
            if ui.button("Register").clicked() {
                *self = Self::default();
                ctx.current_screen = Screens::Register;
            }
        });
    }
}
