use egui::Color32;

use crate::{ctx::ClientCTX, screens::Screens};

#[derive(Default)]
pub struct RegisterScreen {
    email: String,
    password: String,
    repeat_password: String,
    highlight_password: bool,
    highlight_repeat_password: bool,
    highlight_email: bool,
}

impl RegisterScreen {
    pub fn update(&mut self, ctx: &mut ClientCTX, ui: &mut egui::Ui) {
        ui.vertical_centered(|ui| {
            let mut email_field = egui::TextEdit::singleline(&mut self.email).hint_text("Email");
            let mut password_field = egui::TextEdit::singleline(&mut self.password)
                .password(true)
                .hint_text("Password");
            let mut repeat_password_field = egui::TextEdit::singleline(&mut self.repeat_password)
                .password(true)
                .hint_text("Repeat password");
            if self.highlight_email {
                email_field = email_field.background_color(Color32::RED);
            }
            if self.highlight_password {
                password_field = password_field.background_color(Color32::RED);
            }
            if self.highlight_repeat_password {
                repeat_password_field = repeat_password_field.background_color(Color32::RED);
            }
            ui.add(email_field);
            ui.add(password_field);
            ui.add(repeat_password_field);
            if ui.button("Register").clicked() || ui.input(|inp| inp.key_pressed(egui::Key::Enter))
            {
                self.highlight_email = self.email.is_empty();
                self.highlight_password = self.password.is_empty();
                if self.password != self.repeat_password {
                    self.highlight_repeat_password = true;
                    self.highlight_password = true;
                    return;
                }
                if self.highlight_password || self.highlight_email || self.highlight_repeat_password
                {
                    return;
                }
                ctx.password = self.password.clone();
                ctx.email = self.email.clone();
                self.password.clear();
                ctx.current_screen = Screens::Login;
            }
            if ui.button("Back").clicked() {
                *self = Self::default();
                ctx.current_screen = Screens::Login;
            }
        });
    }
}
